Learn R Programming

stlcsb (version 0.1.2)

csb_vacant: Identify Calls for Service Related to Vacancy

Description

csb_vacant appends a logical vector indicating TRUE for vacancy related problem codes.

Usage

csb_vacant(.data, var, newVar)

Arguments

.data

A tibble or data frame

var

Name of existing column containing problem codes

newVar

Name of output variable to be created with vacant logical

Value

Returns a tibble with the logical vector added as a new variable.

Examples

Run this code
# NOT RUN {
csb_vacant(january_2018, var = problemcode, newVar = vacant)

# }

Run the code above in your browser using DataLab