powered by
csb_vacant appends a logical vector indicating TRUE for vacancy related problem codes.
csb_vacant
TRUE
csb_vacant(.data, var, newVar)
A tibble or data frame
Name of existing column containing problem codes
Name of output variable to be created with vacant logical
Returns a tibble with the logical vector added as a new variable.
# NOT RUN { csb_vacant(january_2018, var = problemcode, newVar = vacant) # }
Run the code above in your browser using DataLab